@@ -48,7 +48,7 @@ class KDcrawPriv;
 
 class LIBKDCRAW_EXPORT KDcraw : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
